#
# spec file for package python-aiorpcX
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aiorpcX
Version:        0.23.1
Release:        1.1
Summary:        Generic async RPC implementation, including JSON-RPC
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/kyuupichan/aiorpcX
Source:         https://github.com/kyuupichan/aiorpcX/archive/%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs
Recommends:     python-websockets
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp >= 2.3.2}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module uvloop}
BuildRequires:  %{python_module websockets}
# /SECTION
%python_subpackages

%description
Generic async RPC implementation, including JSON-RPC

%prep
%setup -q -n aiorpcX-%{version}
# needs network
rm tests/test_websocket.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# the two disabled tests below need network
SKIP_TESTS="test_auto_detect_address_failure or test_create_connection_resolve_good"
# test_slow_connection_aborted - randomly fails, out of 10 runs 6 fails
SKIP_TESTS="$SKIP_TESTS or test_slow_connection_aborted"
# test_cancel_remaining_on_group_with_stubborn_task - cannot import create_task -- why? (A new test from 82048a219aac.)
SKIP_TESTS="$SKIP_TESTS or test_cancel_remaining_on_group_with_stubborn_task"
%pytest -k "not ($SKIP_TESTS)"

%files %{python_files}
%doc README.rst
%license LICENCE
%{python_sitelib}/aiorpcx
%{python_sitelib}/aiorpcX-%{version}.dist-info

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.23.1:
  * TaskTimeout now derives from Exception not CancelledError
  * make several tests more robust
  * move to flake8
* Mon May  2 2022 Jiri Slaby <jslaby@suse.cz>
- update to 0.22.1
  * Consume group tasks as they complete
  * Attempt to make tests more robust to timing issues
  * join() waits for tasks to finish
  * Set joined at end of finally clause, just in case
  * Remove obsolete uvloop workaround
  * peername can be None in rare cases it seems
  * Try CRT
  * save some bandwidth: strip redundant whitespaces from json encoding
  * Final updates to TaskGroup() to bring it in line with curio's latest changes
  * Rework cancel_remaining() and expose blocking argument.
  * TaskGroup.join(): don't wait for tasks to cancel if exiting by exception
  * Make TaskGroup.result, exception etc. properties
  * Don't log failed tasks; asyncio does that
  * Add daemonic task tests
  * Bring TaskGroup into line with curio
  * Fix timing issue in test
  * Use a Semaphore not an Event to wake TaskGroup
  * Remove superstitous sleeps.
  * Reduce reliance on timing issues
  * Failed tests must fail the script
  * Require python3.8
* Fri Sep 17 2021 Jiri Slaby <jslaby@suse.cz>
- skip python 3.6. uvloop is not provided there and newer aiorpcx
  requires py >= 3.8 anyway. (But is API incomatible with electrum
  so far.)
* Mon Apr 19 2021 Jiri Slaby <jslaby@suse.cz>
- update to 0.18.7
  * don't wait for tasks to cancel if exiting by exception
  * Fix tests for Python3.8 (we reenable them)
  * Merge pull request #34
  * SOCKS: Fix random auth on Python 3.8+
  * Merge pull request #33
  * session: add method on_disconnect_due_to_excessive_session_cost
* Fri Apr 24 2020 Matej Cepl <mcepl@suse.com>
- Skip over tests failing on Python 3.8 (gh#kyuupichan/aiorpcX#30)
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.18.4
  * handle time.time() not making progress
  * handle SOCKSError in _connect_one
  * socks.py: Add SOCKSRandomAuth
* Wed Jul 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip tests that actually can poll network
* Fri Jun  7 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.18.3
  * Add websocket support as client and server by using Aymeric
    Augustin's excellent websockets package.
  * small bugfixes and improvements
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.5:
  * batches: fix handling of session loss
  * Export normalize_corofunc
* Mon Feb 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip flaky test
* Mon Feb 11 2019 Jiri Slaby <jslaby@suse.com>
- add tests and license
* Wed Feb  6 2019 Jiri Slaby <jslaby@suse.com>
- initial package
